package com.galaxis.manatee.task;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.galaxis.capsule.bo.ChuanyunObject;
import com.galaxis.manatee.constant.ChuanYunConstant;
import com.galaxis.manatee.constant.StringConstant;
import com.galaxis.manatee.dao.*;
import com.galaxis.manatee.entity.chuanyun.data.object.*;
import com.galaxis.manatee.entity.chuanyun.dto.ChuanyunSaveDTO;
import com.galaxis.manatee.entity.chuanyun.dto.Filter;
import com.galaxis.manatee.manager.ChuanYunManager;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * @author zcj
 * @version 0.1
 * @date 2020/4/27 5:14 下午
 */
@Service
@Slf4j
public class ChuanyunBasicDataScheduledTask {

    private final Integer pageSize=20;
    private final ChuanYunManager chuanYunManager;
    private final ChuanyunGroupProjectDao chuanyunGroupProjectDao;
    private final ChuanyunUserDao chuanyunUserDao;
    private final ChuanyunSupplierDao chuanyunSupplierDao;
    private final ChuanyunCompanyDao chuanyunCompanyDao;
    private final ChuanyunUserCompanyDao chuanyunUserCompanyDao;
    private final ChuanyunCostDao chuanyunCostDao;
    private final ChuanyunReimbursementSubjectDao chuanyunReimbursementSubjectDao;
    private final ChuanyunProjectTypeDao chuanyunProjectTypeDao;
    private final ChuanyunSpecialProcedureDao chuanyunSpecialProcedureDao;

    public ChuanyunBasicDataScheduledTask(ChuanYunManager chuanYunManager, ChuanyunGroupProjectDao chuanyunGroupProjectDao, ChuanyunUserDao chuanyunUserDao, ChuanyunSupplierDao chuanyunSupplierDao, ChuanyunCompanyDao chuanyunCompanyDao, ChuanyunUserCompanyDao chuanyunUserCompanyDao, ChuanyunCostDao chuanyunCostDao, ChuanyunReimbursementSubjectDao chuanyunReimbursementSubjectDao, ChuanyunProjectTypeDao chuanyunProjectTypeDao, ChuanyunSpecialProcedureDao chuanyunSpecialProcedureDao) {
        this.chuanYunManager = chuanYunManager;
        this.chuanyunGroupProjectDao = chuanyunGroupProjectDao;
        this.chuanyunUserDao = chuanyunUserDao;
        this.chuanyunSupplierDao = chuanyunSupplierDao;
        this.chuanyunCompanyDao = chuanyunCompanyDao;
        this.chuanyunUserCompanyDao = chuanyunUserCompanyDao;
        this.chuanyunCostDao = chuanyunCostDao;
        this.chuanyunReimbursementSubjectDao = chuanyunReimbursementSubjectDao;
        this.chuanyunProjectTypeDao = chuanyunProjectTypeDao;
        this.chuanyunSpecialProcedureDao = chuanyunSpecialProcedureDao;
    }

    /**
     * 定时将氚云中的数据保存到manatee
     */
    @Scheduled(fixedDelay = 3600000L)
    private void getDataFromChuanyun() {
        //专项费用分摊
        getSpecialProcedure();
        //获取人员-归属公司信息
        getUserCompany();
        //支出档案类型
        getProjectType();
        //获取报销科目
        getReimbursementSubject();
        //获取成本中心
        getCost();
        //获取用户数据
        getUserList();
        //获取集团项目数据
        getGroupProject();
        //获取公司信息
        getCompany();
        //获取供应商
        getSupplier();

    }

    /**
     * 获取用户工号
     */
    @Scheduled(fixedDelay = 1800000L)
    private void getUserEmployeeNumber(){
        chuanyunUserDao.findAll().forEach(chuanyunUserDO -> {
            if(StringUtils.isEmpty(chuanyunUserDO.getEmployeeNumber())){
                ChuanYunConstant.USER_EMPLOYEE_NUMBER.put(chuanyunUserDO.getObjectId(),"");
            }else{
                ChuanYunConstant.USER_EMPLOYEE_NUMBER.put(chuanyunUserDO.getObjectId(),chuanyunUserDO.getEmployeeNumber());
            }
        });
        log.info("用户工号MAP更新完成");
    }

    /**
     * 从氚云中获取用户列表
     */
    private void getUserList() {
        var objectMapper=new ObjectMapper();
        var chuanyunFindAllDTO=chuanYunManager.findAll(ChuanyunUserDO.APP_CODE,ChuanyunUserDO.ACTION_NAME,ChuanyunUserDO.CONTROLLER);
        var totalCount=0;
        try {
            List<ChuanyunUserDO> userList=objectMapper.readValue(chuanyunFindAllDTO.getReturnData().getData(),new TypeReference<>(){});
            totalCount=chuanyunUserDao.saveAll(userList).size();
        } catch (Exception e) {
            e.printStackTrace();
        }
        log.info("用户信息保存保存"+totalCount+"工号映射更新完成");
    }

    /**
     * 从氚云获取集团项目信息
     */
    private void getGroupProject(){
        var objectMapper=new ObjectMapper();
        var start=0;
        var totalCount=0L;
        var flag=true;

        while (flag){
            try {
                //从氚云查询数据
                var filter= Filter.instance(start,start+pageSize,true);
                var chuanyunFindAllResponse=chuanYunManager.findAll(ChuanyunGroupProjectDO.SCHEMA_CODE,filter);
                if(chuanyunFindAllResponse.getReturnData()==null){
                    flag=false;
                    continue;
                }
                if(chuanyunFindAllResponse.getReturnData().getTotalCount()>=start+pageSize){
                    start+=pageSize;
                }else{
                    flag=false;
                }
                //转化为POJO
                List<ChuanyunGroupProjectDO> result=objectMapper.convertValue(chuanyunFindAllResponse.getReturnData().getBizObjectArray(), new TypeReference<>(){});
                //获取项目总数
                totalCount=chuanyunFindAllResponse.getReturnData().getTotalCount();
                //保存
                result.forEach(chuanyunGroupProjectDO ->  {
                    var tmpGroupProjectDO=chuanyunGroupProjectDao.findById(chuanyunGroupProjectDO.getObjectId());
                    tmpGroupProjectDO.ifPresent(projectDO -> {
                        chuanyunGroupProjectDO.setIsCreate(projectDO.getIsCreate());
                        chuanyunGroupProjectDao.delete(tmpGroupProjectDO.get());
                    });

                    //处理项目对象中的项目成员数据
                    projectMemberCheck(chuanyunGroupProjectDO);
                    //处理项目对象中的项目经理、项目负责人数据
                    projectManagerCheck(chuanyunGroupProjectDO);
                });
                chuanyunGroupProjectDao.saveAll(result);
            }catch (Exception e){
                log.error(e.getMessage());
                e.printStackTrace();
            }
        }
        log.info("集团项目信息保存保存"+totalCount+"项目映射更新完成");
    }

    /**
     * 通过更新集团项目中的项目负责人、EBG项目经理、IBG项目经理
     * @param chuanyunGroupProjectDO    项目对象
     */
    private void projectManagerCheck(ChuanyunGroupProjectDO chuanyunGroupProjectDO){
        //将projectManger和projectOwner替换为主键
        if(!StringUtils.isEmpty(chuanyunGroupProjectDO.getProjectOwner())){
            chuanyunGroupProjectDO.setProjectOwner(chuanyunGroupProjectDO.getProjectOwnerObject().getObjectId());
        }
        if (!StringUtils.isEmpty(chuanyunGroupProjectDO.getEbgProjectManager())){
            chuanyunGroupProjectDO.setEbgProjectManager(chuanyunGroupProjectDO.getEbgProjectManagerObject().getObjectId());
        }
        if(!StringUtils.isEmpty(chuanyunGroupProjectDO.getIbgProjectManager())){
            chuanyunGroupProjectDO.setIbgProjectManager(chuanyunGroupProjectDO.getIbgProjectManagerObject().getObjectId());
        }
        var objectMapper=new ObjectMapper();
        //第一步，清除项目负责人、项目经理数据。保证能够触发权限修改流程
        GroupProjectUpdateDTO groupProjectUpdateDTO=new GroupProjectUpdateDTO();
        try {
            chuanYunManager.update(ChuanyunGroupProjectDO.SCHEMA_CODE,chuanyunGroupProjectDO.getObjectId(),objectMapper.writeValueAsString(groupProjectUpdateDTO));
        } catch (Exception e) {
            e.printStackTrace();
            log.warn(chuanyunGroupProjectDO.getObjectId()+"更新项目经理失败"+e.getMessage());
        }
        groupProjectUpdateDTO=new GroupProjectUpdateDTO(chuanyunGroupProjectDO);
        //保证项目经理信息更新成功
        boolean updateFlag=false;
        while (!updateFlag){
            try {
                var groupProjectUpdateString=objectMapper.writeValueAsString(groupProjectUpdateDTO);
                ChuanyunSaveDTO chuanyunSaveDTO=chuanYunManager.update(ChuanyunGroupProjectDO.SCHEMA_CODE,chuanyunGroupProjectDO.getObjectId(),groupProjectUpdateString);
                if(chuanyunSaveDTO.getSuccessful()){
                    log.info(chuanyunGroupProjectDO.getObjectId()+"更新项目经理成功"+groupProjectUpdateString);
                    updateFlag=true;
                    //更新成功之后重新获取集团项目组信息，防止id为空
                    var chuanyunFindResponse =  chuanYunManager.find(ChuanyunGroupProjectDO.SCHEMA_CODE,chuanyunGroupProjectDO.getObjectId());
                    ChuanyunGroupProjectDO tmpChuanyunGroupProjectDO = objectMapper.convertValue(chuanyunFindResponse.getReturnData().getBizObject(), new TypeReference<>(){});
                    chuanyunGroupProjectDO.setDetailList(tmpChuanyunGroupProjectDO.getDetailList());
                }else{
                    log.warn(chuanyunGroupProjectDO.getObjectId()+"更新项目经理失败"+groupProjectUpdateString);
                    log.warn(chuanyunGroupProjectDO+"");
                    Thread.sleep(5000L);
                }
            } catch (Exception e) {
                e.printStackTrace();
                log.warn(chuanyunGroupProjectDO.getObjectId()+"更新项目经理失败"+e.getMessage());
            }
        }
    }

    /**
     * 如果有项目组成员，将项目组成员projectMember替换为主键
     * 如果没有项目组成员，判断是否是EBG的实施、研发二开、售后维保项目，如果是，则添加EBG全体成员
     * @param chuanyunGroupProjectDO    项目对象
     */
    private void projectMemberCheck(ChuanyunGroupProjectDO chuanyunGroupProjectDO){
        if (chuanyunGroupProjectDO.getProjectMemberList() != null) {
            List<String> memberList = new ArrayList<>();
            var builder = new StringBuilder();
            for (ChuanyunObject chuanyunObject: chuanyunGroupProjectDO.getProjectMemberObject()) {
                builder.append(chuanyunObject.getObjectId()).append(StringConstant.SEMICOLON);
                memberList.add(chuanyunObject.getObjectId());
            }
            chuanyunGroupProjectDO.setProjectMember(builder.toString());
            //替换为主键后更新氚云数据表来增加权限
            chuanyunGroupProjectDO.setProjectMemberList(memberList.toArray(new String[0]));
        }else {
            //项目成员为空的情况判断
            //判断项目BG是否为EBG
            var specifiedBusinessGroupFlag=ChuanyunGroupProjectDO.EBG.equals(chuanyunGroupProjectDO.getBusinessGroup());
            //判断项目类型是否为 下列项目类型中的一种
            var specifiedProjectTypeFlag=("实施".equals(chuanyunGroupProjectDO.getProjectType())||
                    "维保".equals(chuanyunGroupProjectDO.getProjectType())||
                    "研发二开".equals(chuanyunGroupProjectDO.getProjectType())||
                    "售后".equals(chuanyunGroupProjectDO.getProjectType()));
            //如果项目组成员为空，则自动为项目添加所有EBG成员作为项目组成员
            if (specifiedBusinessGroupFlag&&specifiedProjectTypeFlag) {
                var projectMember = new ArrayList<String>();
                var builder = new StringBuilder();
                ChuanYunConstant.USER_BUSINESS_GROUP.forEach((k,v)->{
                    if (ChuanyunGroupProjectDO.EBG.equals(v)&&null!=k){
                        builder.append(k).append(StringConstant.SEMICOLON);
                        projectMember.add(k);
                    }
                });
                //TODO 这里可能存在chuanyunCompanyDO找不到的情况,防止NPE,我把下面的代码换成了上面的形式--钟崇杰
//                for (ChuanyunUserCompanyDO chuanyunUserCompanyDO : chuanyunUserCompanyDao.findAll()) {
//                    if ("EBG".equals(chuanyunCompanyDao.findByObjectId(chuanyunUserCompanyDO.getCompanyId()).getBusinessGroup())) {
//                        builder.append(chuanyunUserCompanyDO.getUserId()).append(StringConstant.SEMICOLON);
//                        projectMember.add(chuanyunUserCompanyDO.getUserId());
//                    }
//                }
                chuanyunGroupProjectDO.setProjectMember(builder.toString());
                chuanyunGroupProjectDO.setProjectMemberList(projectMember.toArray(new String[0]));
                log.info("成员已更新"+chuanyunGroupProjectDO.getProjectCode()+chuanyunGroupProjectDO.getProjectType());
            }
        }
    }

    /**
     * 获取供应商信息
     */
    private void getSupplier(){
        var objectMapper=new ObjectMapper();
        var start=0;
        var totalCount=0L;
        var flag=true;
        while (flag){
            try {
                //从氚云查询数据
                var filter= Filter.instance(start,start+pageSize,true);
                var chuanyunFindAllResponse=chuanYunManager.findAll(ChuanyunSupplierDO.SCHEMA_CODE,filter);
                if(chuanyunFindAllResponse.getReturnData()==null){
                    flag=false;
                    continue;
                }
                if(chuanyunFindAllResponse.getReturnData().getTotalCount()>=start+pageSize){
                    start+=pageSize;
                }else{
                    flag=false;
                }
                //转化为POJO
                List<ChuanyunSupplierDO> result=objectMapper.convertValue(chuanyunFindAllResponse.getReturnData().getBizObjectArray(), new TypeReference<>(){});
                //获取项目总数
                totalCount=chuanyunFindAllResponse.getReturnData().getTotalCount();
                //保存
                chuanyunSupplierDao.saveAll(result);
            }catch (Exception e){
                log.error(e.getMessage());
                e.printStackTrace();
            }
        }
        log.info("供应商信息保存保存"+totalCount);
    }

    /**
     * 更新支出档案类型
     */
    public void getProjectType() {
        var objectMapper=new ObjectMapper();
        var start=0;
        var totalCount=0L;
        var flag=true;
        while (flag) {
            try {
                //从氚云查询数据
                var filter = Filter.instance(start, start + pageSize, true);
                var chuanyunFindAllResponse = chuanYunManager.findAll(ChuanyunProjectTypeDO.SCHEMA_CODE, filter);
                if (chuanyunFindAllResponse.getReturnData() == null) {
                    flag = false;
                    continue;
                }
                if (chuanyunFindAllResponse.getReturnData().getTotalCount() >= start + pageSize) {
                    start += pageSize;
                } else {
                    flag = false;
                }
                //转化为POJO
                List<ChuanyunProjectTypeDO> result = objectMapper.convertValue(chuanyunFindAllResponse.getReturnData().getBizObjectArray(), new TypeReference<>(){});
                //获取项目总数
                totalCount=chuanyunFindAllResponse.getReturnData().getTotalCount();
                //保存
                chuanyunProjectTypeDao.saveAll(result);
            }catch (Exception e) {
                log.error(e.getMessage());
                e.printStackTrace();
            }
            log.info("支出档案类型"+totalCount);
        }
    }

    /**
     * 更新公司信息
     */
    private void getCompany(){
        var objectMapper=new ObjectMapper();
        var start=0;
        var totalCount=0L;
        var flag=true;
        while (flag){
            try {
                //从氚云查询数据
                var filter= Filter.instance(start,start+pageSize,true);
                var chuanyunFindAllResponse=chuanYunManager.findAll(ChuanyunCompanyDO.SCHEMA_CODE,filter);
                if(chuanyunFindAllResponse.getReturnData()==null){
                    flag=false;
                    continue;
                }
                if(chuanyunFindAllResponse.getReturnData().getTotalCount()>=start+pageSize){
                    start+=pageSize;
                }else{
                    flag=false;
                }
                //转化为POJO
                List<ChuanyunCompanyDO> result=objectMapper.convertValue(chuanyunFindAllResponse.getReturnData().getBizObjectArray(), new TypeReference<>(){});
                //获取项目总数
                totalCount=chuanyunFindAllResponse.getReturnData().getTotalCount();
                //保存
                chuanyunCompanyDao.saveAll(result);
            }catch (Exception e){
                log.error(e.getMessage());
                e.printStackTrace();
            }
        }
        log.info("公司信息保存保存"+totalCount);
    }

    /**
     * 更新成本中心
     */
    private void getCost(){
        var objectMapper=new ObjectMapper();
        var start=0;
        var totalCount=0L;
        var flag=true;
        while (flag){
            try {
                //从氚云查询数据
                var filter= Filter.instance(start,start+pageSize,true);
                var chuanyunFindAllResponse=chuanYunManager.findAll(ChuanyunCostDO.SCHEMA_CODE,filter);
                if(chuanyunFindAllResponse.getReturnData()==null){
                    flag=false;
                    continue;
                }
                if(chuanyunFindAllResponse.getReturnData().getTotalCount()>=start+pageSize){
                    start+=pageSize;
                }else{
                    flag=false;
                }
                //转化为POJO
                List<ChuanyunCostDO> result=objectMapper.convertValue(chuanyunFindAllResponse.getReturnData().getBizObjectArray(), new TypeReference<>(){});
                //获取项目总数
                totalCount=chuanyunFindAllResponse.getReturnData().getTotalCount();
                //保存
                chuanyunCostDao.saveAll(result);
            }catch (Exception e){
                log.error(e.getMessage());
                e.printStackTrace();
            }
        }
        log.info("成本中心保存保存"+totalCount);
    }

    /**
     * 获取专项分摊规则
     */
    private void getSpecialProcedure(){
        var objectMapper=new ObjectMapper();
        var start=0;
        var totalCount=0L;
        var flag=true;
        while (flag){
            try {
                //从氚云查询数据
                var filter= Filter.instance(start,start+pageSize,true);
                var chuanyunFindAllResponse=chuanYunManager.findAll(ChuanyunSpecialProcedureDO.SCHEMA_CODE,filter);
                if(chuanyunFindAllResponse.getReturnData()==null){
                    flag=false;
                    continue;
                }
                if(chuanyunFindAllResponse.getReturnData().getTotalCount()>=start+pageSize){
                    start+=pageSize;
                }else{
                    flag=false;
                }
                //转化为POJO
                List<ChuanyunSpecialProcedureDO> result=objectMapper.convertValue(chuanyunFindAllResponse.getReturnData().getBizObjectArray(), new TypeReference<>(){});
                //获取项目总数
                totalCount=chuanyunFindAllResponse.getReturnData().getTotalCount();
                //保存
                chuanyunSpecialProcedureDao.saveAll(result);
            }catch (Exception e){
                log.error(e.getMessage());
                e.printStackTrace();
            }
        }
        log.info("专项分摊信息保存保存"+totalCount);
    }

    /**
     * 获取人员-归属公司信息
     */
    private void getUserCompany(){
        var objectMapper=new ObjectMapper();
        var start=0;
        var totalCount=0L;
        var flag=true;
        while (flag){
            try {
                //从氚云查询数据
                var filter= Filter.instance(start,start+pageSize,true);
                var chuanyunFindAllResponse=chuanYunManager.findAll(ChuanyunUserCompanyDO.SCHEMA_CODE,filter);
                if(chuanyunFindAllResponse.getReturnData()==null){
                    flag=false;
                    continue;
                }
                if(chuanyunFindAllResponse.getReturnData().getTotalCount()>=start+pageSize){
                    start+=pageSize;
                }else{
                    flag=false;
                }
                //转化为POJO
                List<ChuanyunUserCompanyDO> result=objectMapper.convertValue(chuanyunFindAllResponse.getReturnData().getBizObjectArray(), new TypeReference<>(){});
                //获取项目总数
                totalCount=chuanyunFindAllResponse.getReturnData().getTotalCount();
                //保存
                result.forEach(chuanyunUserCompanyDO -> {
                    try {
                        if(chuanyunUserCompanyDO.getUser()!=null){
                            chuanyunUserCompanyDO.setUserId(chuanyunUserCompanyDO.getUser().getObjectId());
                        }
                    }catch (Exception exception){
                        log.warn(chuanyunUserCompanyDO+"");
                        log.warn(exception.getMessage());
                    }
                    try{
                        ChuanYunConstant.USER_BUSINESS_GROUP.put(chuanyunUserCompanyDO.getUserId(),chuanyunCompanyDao.findByObjectId(chuanyunUserCompanyDO.getCompanyId()).getBusinessGroup());
                    }catch (Exception e){
                        log.warn("更新用户BG信息时发生异常"+e.getMessage());
                    }
                    ChuanYunConstant.USER_DEPARTMENT.put(chuanyunUserCompanyDO.getUserId(),chuanyunUserCompanyDO.getDepartmentObject().getObjectId());
                });
                chuanyunUserCompanyDao.saveAll(result);
            }catch (Exception e){
                log.error(e.getMessage());
                e.printStackTrace();
            }
        }
        log.info("人员归属公司信息保存保存"+totalCount);
    }

    /**
     * 获取报销科目
     */
    private void getReimbursementSubject(){
        var objectMapper=new ObjectMapper();
        var start=0;
        var totalCount=0L;
        var flag=true;
        while (flag){
            try {
                //从氚云查询数据
                var filter= Filter.instance(start,start+pageSize,true);
                var chuanyunFindAllResponse=chuanYunManager.findAll(ChuanyunReimbursementSubjectDO.SCHEMA_CODE,filter);
                if(chuanyunFindAllResponse.getReturnData()==null){
                    flag=false;
                    continue;
                }
                if(chuanyunFindAllResponse.getReturnData().getTotalCount()>=start+pageSize){
                    start+=pageSize;
                }else{
                    flag=false;
                }
                //转化为POJO
                List<ChuanyunReimbursementSubjectDO> result=objectMapper.convertValue(chuanyunFindAllResponse.getReturnData().getBizObjectArray(), new TypeReference<>(){});
                //获取项目总数
                totalCount=chuanyunFindAllResponse.getReturnData().getTotalCount();
                //保存
                chuanyunReimbursementSubjectDao.saveAll(result);
            }catch (Exception e){
                log.error(e.getMessage());
                e.printStackTrace();
            }
        }
        log.info("报销科目信息保存保存"+totalCount);
    }

    /**
     * 用于刷新项目经理权限的对象
     */
    @Data
    class GroupProjectUpdateDTO{
        /**
         * 项目总监
         * U9项目责任人
         */
        @JsonProperty(value = "F0000006")
        private String projectOwner;

        /**
         * IBG项目经理
         */
        @JsonProperty("F0000012")
        private String ibgProjectManager;

        /**
         * EBG项目经理
         */
        @JsonProperty("F0000011")
        private String ebgProjectManager;

//        /**
//         * 项目组成员（前端传数据用）
//         */
//        @JsonProperty("F0000034")
//        private String[] projectMemberList;

//        /**
//         * 项目组织信息
//         * TODO 这个DTO是用于更新氚云数据的，不需要使用@OneToMany注解吧？使用目的是啥
//         */
//        @OneToMany(cascade = CascadeType.ALL, orphanRemoval = true,fetch = FetchType.EAGER)
//        @JsonProperty("D001789Fd992bf8fbe114c9babe0f98cf676f8a2")
////        @JsonProperty("D001789Fvspc68z01idftf5nqt66pkuc0")
//        private List<ChuanyunGroupProjectDetailDO> detailList;

        public GroupProjectUpdateDTO() {
        }

        public GroupProjectUpdateDTO(ChuanyunGroupProjectDO chuanyunGroupProjectDO) {
            if(null!=chuanyunGroupProjectDO){
                if(null!=chuanyunGroupProjectDO.getProjectOwnerObject()){
                    this.projectOwner=chuanyunGroupProjectDO.getProjectOwnerObject().getObjectId();
                }
                if(null!=chuanyunGroupProjectDO.getIbgProjectManagerObject()){
                    this.ibgProjectManager=chuanyunGroupProjectDO.getIbgProjectManagerObject().getObjectId();
                }
                if(null!=chuanyunGroupProjectDO.getEbgProjectManagerObject()){
                    this.ebgProjectManager=chuanyunGroupProjectDO.getEbgProjectManagerObject().getObjectId();
                }
                //TODO 更新项目经理时更新项目组织信息会是这两个业务流程耦合，不方便后续维护需要考虑单独一个DTO作为更新项目组织信息的对象
//                if(null!=chuanyunGroupProjectDO.getProjectMemberList()){
//                    this.projectMemberList =chuanyunGroupProjectDO.getProjectMemberList();
//                }
//                if(null!=chuanyunGroupProjectDO.getDetailList()){
//                    this.detailList=chuanyunGroupProjectDO.getDetailList();
//                }
            }
        }
    }
}
